@@ -42,7 +42,7 @@ enum
 {
   PROP_0,
 
-  PROP_TYPE,
+  PROP_TYPE
 };
 
 static void		gconf_editor_window_set_property	(GObject          *object,
@@ -1271,6 +1271,8 @@ gconf_editor_window_style_set (GtkWidget *widget, GtkStyle *prev_style, GtkWidge
 {
 	gtk_widget_modify_base (text_view, GTK_STATE_NORMAL,
 				&GTK_WIDGET (widget)->style->bg[GTK_STATE_NORMAL]);
+	gtk_widget_modify_text (text_view, GTK_STATE_NORMAL,
+				&GTK_WIDGET (widget)->style->fg[GTK_STATE_NORMAL]);
 }
 
 void
@@ -1286,46 +1288,33 @@ gconf_editor_window_expand_first (GConfEditorWindow *window)
 static GConfClient*
 gconf_editor_window_get_client (int type)
 {
-	static GConfClient *defaults_client = NULL;
-	static GConfClient *mandatory_client = NULL;
-
 	GConfEngine *engine;
 	GConfClient *client = NULL;
-        GError *error = NULL;
+	GError *error = NULL;
 
 	switch (type) {
 	case GCONF_EDITOR_WINDOW_TYPE_NORMAL:
 		client = gconf_client_get_default ();
 		break;
 	case GCONF_EDITOR_WINDOW_TYPE_DEFAULTS:
-		if (defaults_client != NULL) {
-			client = defaults_client;
-			g_object_ref (defaults_client);
-		} else {
-			engine = gconf_engine_get_for_address (GCONF_DEFAULTS_SOURCE, &error);
-			if (error) {
-				gconf_editor_window_popup_error_dialog (NULL,
-				_("Cannot create GConf engine. Error was:\n%s"), error);
-				return NULL;
-			}
-			client = gconf_client_get_for_engine (engine);
-			gconf_engine_unref (engine);
+		engine = gconf_engine_get_for_address (GCONF_DEFAULTS_SOURCE, &error);
+		if (error) {
+			gconf_editor_window_popup_error_dialog (NULL,
+			_("Cannot create GConf engine. Error was:\n%s"), error);
+			return NULL;
 		}
+		client = gconf_client_get_for_engine (engine);
+		gconf_engine_unref (engine);
 		break;
 	case GCONF_EDITOR_WINDOW_TYPE_MANDATORY:
-		if (mandatory_client != NULL) {
-			client = mandatory_client;
-			g_object_ref (mandatory_client);
-		} else {
-			engine = gconf_engine_get_for_address (GCONF_MANDATORY_SOURCE, &error);
-			if (error) {
-				gconf_editor_window_popup_error_dialog (NULL,
-				_("Cannot create GConf engine. Error was:\n%s"), error);
-				return NULL;
-			}
-			client = gconf_client_get_for_engine (engine);
-			gconf_engine_unref (engine);
+		engine = gconf_engine_get_for_address (GCONF_MANDATORY_SOURCE, &error);
+		if (error) {
+			gconf_editor_window_popup_error_dialog (NULL,
+			_("Cannot create GConf engine. Error was:\n%s"), error);
+			return NULL;
 		}
+		client = gconf_client_get_for_engine (engine);
+		gconf_engine_unref (engine);
 		break;
 	default:
 		g_assert_not_reached ();
