@@ -34,8 +34,7 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-popup-menu.h>
+#include <glib/gi18n.h>
 
 #include "gedit-output-window.h"
 
@@ -283,6 +282,35 @@ create_popup_menu (GeditOutputWindow  *output_window)
 	return menu;
 }
 
+static gint
+my_popup_handler (GtkWidget *widget, GdkEvent *event)
+{
+  GtkMenu *menu;
+  GdkEventButton *event_button;
+
+  g_return_val_if_fail (widget != NULL, FALSE);
+  g_return_val_if_fail (GTK_IS_MENU (widget), FALSE);
+  g_return_val_if_fail (event != NULL, FALSE);
+
+  /* The "widget" is the menu that was supplied when 
+   * g_signal_connect_swapped() was called.
+   */
+  menu = GTK_MENU (widget);
+
+  if (event->type == GDK_BUTTON_PRESS)
+    {
+      event_button = (GdkEventButton *) event;
+      if (event_button->button == 3)
+	{
+	  gtk_menu_popup (menu, NULL, NULL, NULL, NULL, 
+			  event_button->button, event_button->time);
+	  return TRUE;
+	}
+    }
+
+  return FALSE;
+}
+
 static void
 gedit_output_window_treeview_selection_changed (GtkTreeSelection *selection, 
 						GeditOutputWindow  *output_window)
@@ -481,7 +509,11 @@ gedit_output_window_init (GeditOutputWindow  *output_window)
 
 	popup_menu = create_popup_menu (output_window);
 		
-	gnome_popup_menu_attach (popup_menu, output_window->priv->treeview, NULL);
+	gtk_menu_attach_to_widget(GTK_MENU(popup_menu), output_window->priv->treeview, NULL);
+	
+	g_signal_connect_swapped (output_window->priv->treeview, "button_press_event",	G_CALLBACK (my_popup_handler), popup_menu);
+	
+			  
 }
 
 static void 
